summaryrefslogtreecommitdiffstats
path: root/webkit/tools/test_shell/webview_host.h
diff options
context:
space:
mode:
authoragl@chromium.org <agl@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-12-11 21:50:41 +0000
committeragl@chromium.org <agl@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-12-11 21:50:41 +0000
commit5590f8286b568b29e67f0d575dad0cb84f071e87 (patch)
tree76a5cc4ce0cdb148a3a4d258104e1f249878bc91 /webkit/tools/test_shell/webview_host.h
parent35a61135047d83c9b87fdb57f86367c05efeeb26 (diff)
downloadchromium_src-5590f8286b568b29e67f0d575dad0cb84f071e87.zip
chromium_src-5590f8286b568b29e67f0d575dad0cb84f071e87.tar.gz
chromium_src-5590f8286b568b29e67f0d575dad0cb84f071e87.tar.bz2
Rename ViewHandle to NativeView et al.
ViewHandle is a very unfortunate name when we actually start dealing with views, so we are renaming the cross-platform typedefs to make it clear that they refer to platform specific native UI elements. Review URL: http://codereview.chromium.org/13754 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@6826 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'webkit/tools/test_shell/webview_host.h')
-rw-r--r--webkit/tools/test_shell/webview_host.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/webkit/tools/test_shell/webview_host.h b/webkit/tools/test_shell/webview_host.h
index 9a1e719..86dba37 100644
--- a/webkit/tools/test_shell/webview_host.h
+++ b/webkit/tools/test_shell/webview_host.h
@@ -15,13 +15,13 @@ struct WebPreferences;
class WebView;
class WebViewDelegate;
// This class is a simple ViewHandle-based host for a WebView
class WebViewHost : public WebWidgetHost {
public:
// The new instance is deleted once the associated ViewHandle is destroyed.
// The newly created window should be resized after it is created, using the
// MoveWindow (or equivalent) function.
- static WebViewHost* Create(gfx::WindowHandle parent_window,
+ static WebViewHost* Create(gfx::NativeWindow parent_window,
WebViewDelegate* delegate,
const WebPreferences& prefs);
@@ -15,13 +15,13 @@ struct WebPreferences;
class WebView;
class WebViewDelegate;
-// This class is a simple ViewHandle-based host for a WebView
+// This class is a simple NativeView-based host for a WebView
class WebViewHost : public WebWidgetHost {
public:
@@ -15,13 +15,13 @@ struct WebPreferences;
class WebViewHost : public WebWidgetHost {
public:
- // The new instance is deleted once the associated ViewHandle is destroyed.
+ // The new instance is deleted once the associated NativeView is destroyed.
// The newly created window should be resized after it is created, using the
// MoveWindow (or equivalent) function.